@@ -234,8 +234,36 @@
  *
  * 2004-10-13: 1024 -> 4096
  */
-#ifndef MAXCONNECTIONS
-#define MAXCONNECTIONS	10240
+#ifdef _WIN32
+ #define MAXCONNECTIONS	10240
+#else
+ /* Non-Windows: */
+ #if (!defined(MAXCONNECTIONS_REQUEST) || (MAXCONNECTIONS_REQUEST < 1)) && \
+      (defined(HAVE_POLL) || defined(HAVE_EPOLL) || defined(HAVE_KQUEUE))
+  /* Have poll/epoll/kqueue and either no --with-maxconnections or
+   * --with-maxconnections=0, either of which indicates 'automatic' mode.
+   * At the time of writing we will try a limit of 8192.
+   * It will automatically be lowered at boottime if we can only use
+   * 4096, 2048 or 1024. No problem.
+   */
+  #define MAXCONNECTIONS 8192
+ #elif defined(MAXCONNECTIONS_REQUEST) && (MAXCONNECTIONS_REQUEST >= 1)
+  /* --with-maxconnections=something */
+  #define MAXCONNECTIONS MAXCONNECTIONS_REQUEST
+ #else
+  /* Automatic mode, but we only have select(). Bummer... */
+  #define MAXCONNECTIONS 1024
+ #endif
+#endif
+
+/* Number of file descriptors reserved for non-incoming-clients.
+ * One of which may be used by auth, the rest are really reserved.
+ * They can be used for outgoing server links, listeners, logging, etc.
+ */
+#if MAXCONNECTIONS > 1024
+ #define CLIENTS_RESERVE 8
+#else
+ #define CLIENTS_RESERVE 4
 #endif
 
 /*
@@ -287,9 +315,6 @@
 #define SPAMFILTER_DETECTSLOW
 #endif
 
-/* Use TRE Regex Library (as well) ? */
-#define USE_TRE
-
 /* Maximum number of ModData objects that may be attached to an object */
 /* UnrealIRCd 4.0.0 - 4.0.13:  8, 8, 4, 4
  * UnrealIRCd 4.0.14+       : 12, 8, 4, 4
@@ -407,11 +432,6 @@ error You stuffed up config.h signals
 #ifdef	POSIX_SIGNALS
 #define	HAVE_RELIABLE_SIGNALS
 #endif
-/*
- * safety margin so we can always have one spare fd, for motd/authd or
- * whatever else.  -4 allows "safety" margin of 1 and space reserved.
- */
-#define	MAXCLIENTS	(MAXCONNECTIONS-4)
 #ifdef HAVECURSES
 # define DOCURSES
 #else
@@ -456,12 +476,6 @@ error You stuffed up config.h signals
 #if defined(SOL20) || defined(SOL25) || defined(SOL26) || defined(SOL27)
 #define _SOLARIS
 #endif
-/*
- * Cleaup for WIN32 platform.
- */
-#ifdef _WIN32
-# undef FORCE_CORE
-#endif
 #ifdef NEED_BCMP
 #define bcmp memcmp
 #endif
