@@ -426,8 +426,8 @@ struct _irccallback {
  * for things like do_join, join_channel, etc.
  * The difference between callbacks and efunctions are:
  * - efunctions are mandatory, while callbacks can be optional (depends!)
- * - efunctions are ment for internal usage, so 3rd party modules are not allowed
- *   to add them.
+ * - efunctions are meant for internal usage, so 3rd party modules are
+ *   not allowed to add them.
  * - all efunctions are declared as function pointers in modules.c
  */
 struct _ircefunction {
@@ -711,11 +711,13 @@ extern Callback	*CallbackDel(Callback *cb);
 extern Efunction	*EfunctionAddMain(Module *module, int eftype, int (*intfunc)(), void (*voidfunc)(), void *(*pvoidfunc)(), char *(*pcharfunc)());
 extern Efunction	*EfunctionDel(Efunction *cb);
 
-extern Command *CommandAdd(Module *module, char *cmd, int (*func)(aClient *cptr, aClient *sptr, int parc, char *parv[]), unsigned char params, int flags);
+extern Command *CommandAdd(Module *module, char *cmd, CmdFunc func, unsigned char params, int flags);
+extern Command *AliasAdd(Module *module, char *cmd, AliasCmdFunc aliasfunc, unsigned char params, int flags);
 extern void CommandDel(Command *command);
+extern void CommandDelX(Command *command, aCommand *cmd);
 extern int CommandExists(char *name);
-extern Cmdoverride *CmdoverrideAdd(Module *module, char *cmd, int (*func)(Cmdoverride *ovr, aClient *cptr, aClient *sptr, int parc, char *parv[]));
-extern Cmdoverride *CmdoverrideAddEx(Module *module, char *name, int priority, int (*func)(Cmdoverride *ovr, aClient *cptr, aClient *sptr, int parc, char *parv[]));
+extern Cmdoverride *CmdoverrideAdd(Module *module, char *cmd, OverrideCmdFunc func);
+extern Cmdoverride *CmdoverrideAddEx(Module *module, char *name, int priority, OverrideCmdFunc func);
 extern void CmdoverrideDel(Cmdoverride *ovr);
 extern int CallCmdoverride(Cmdoverride *ovr, aClient *cptr, aClient *sptr, int parc, char *parv[]);
 
@@ -1043,6 +1045,7 @@ _UNREAL_ERROR(_hook_error_incompatible, "Incompatible hook function. Check argum
 #define CALLBACKTYPE_CLOAKKEYCSUM 2
 #define CALLBACKTYPE_CLOAK_EX 3
 #define CALLBACKTYPE_BLACKLIST_CHECK 4
+#define CALLBACKTYPE_REPUTATION_STARTTIME 5
 
 /* Efunction types */
 #define EFUNC_DO_JOIN       				1
@@ -1101,6 +1104,7 @@ _UNREAL_ERROR(_hook_error_incompatible, "Incompatible hook function. Check argum
 #define EFUNC_DO_NICK_NAME			57
 #define EFUNC_DO_REMOTE_NICK_NAME	58
 #define EFUNC_CHARSYS_GET_CURRENT_LANGUAGES	59
+#define EFUNC_BROADCAST_SINFO		60
 
 /* Module flags */
 #define MODFLAG_NONE	0x0000
