@@ -59,7 +59,9 @@
 # endif
 #endif
 #include "auth.h" 
+#ifdef USE_TRE
 #include "tre/regex.h"
+#endif
 #define PCRE2_CODE_UNIT_WIDTH 8
 #include "pcre2.h"
 
@@ -602,9 +604,7 @@ struct aloopStruct {
 typedef enum {
 	MATCH_SIMPLE=1, /**< Simple pattern with * and ? */
 	MATCH_PCRE_REGEX=2, /**< PCRE2 Perl-like regex (new) */
-#ifdef USE_TRE
 	MATCH_TRE_REGEX=3, /**< TRE POSIX regex (old, unreal3.2.x) */
-#endif
 } MatchType;
 
 /** Match struct, which allows various matching styles, see MATCH_* */
@@ -696,8 +696,9 @@ struct Server {
 	char 		*up;		/* uplink for this server */
 	char 		by[NICKLEN + 1];
 	ConfigItem_link *conf;
-	TS   		timestamp;		/* Remotely determined connect try time */
-	long		 users;
+	TS   		timestamp;	/* Remotely determined connect try time */
+	long		users;
+	TS		boottime;	/* Startup time of server */
 #ifdef	LIST_DEBUG
 	aClient *bcptr;
 #endif
@@ -706,9 +707,11 @@ struct Server {
 		unsigned server_sent:1;		/* SERVER message sent to this link? (for outgoing links) */
 	} flags;
 	struct {
+		char *usermodes;
 		char *chanmodes[4];
 		int protocol;
 		char *software;
+		char *nickchars;
 	} features;
 };
 
@@ -794,6 +797,10 @@ typedef struct ircstatsx {
 
 extern MODVAR ircstats IRCstats;
 
+typedef int (*CmdFunc)(aClient *cptr, aClient *sptr, int parc, char *parv[]);
+typedef int (*AliasCmdFunc)(aClient *cptr, aClient *sptr, int parc, char *parv[], char *cmd);
+typedef int (*OverrideCmdFunc)(Cmdoverride *ovr, aClient *cptr, aClient *sptr, int parc, char *parv[]);
+
 #include "modules.h"
 
 extern MODVAR Umode *Usermode_Table;
@@ -1554,12 +1561,65 @@ struct DSlink {
 		char *cp;
 	} value;
 };
-#define AddListItem(item,list) add_ListItem((ListStruct *)item, (ListStruct **)&list)
-#define AppendListItem(item,list) append_ListItem((ListStruct *)item, (ListStruct **)&list)
-#define DelListItem(item,list) del_ListItem((ListStruct *)item, (ListStruct **)&list)
+#ifndef _WIN32
+ #define CHECK_LIST_ENTRY(list)		if (offsetof(typeof(*list),prev) != offsetof(ListStruct,prev)) \
+					{ \
+						ircd_log(LOG_ERROR, "[BUG] %s:%d: List operation on struct with incorrect order (->prev must be 1st struct member)", __FILE__, __LINE__); \
+						abort(); \
+					} \
+					if (offsetof(typeof(*list),next) != offsetof(ListStruct,next)) \
+					{ \
+						ircd_log(LOG_ERROR, "[BUG] %s:%d: List operation on struct with incorrect order (->next must be 2nd struct member))", __FILE__, __LINE__); \
+						abort(); \
+					}
+#else
+ #define CHECK_LIST_ENTRY(list)		/* not available on Windows, typeof() not reliable */
+#endif
 
-#define AddListItemPrio(item,list,prio) add_ListItemPrio((ListStructPrio *)item, (ListStructPrio **)&list, prio)
-#define DelListItemPrio(item,list,prio) del_ListItem((ListStruct *)item, (ListStruct **)&list)
+#define AddListItem(item,list)		do { \
+						CHECK_LIST_ENTRY(list) \
+						add_ListItem((ListStruct *)item, (ListStruct **)&list); \
+					} while(0)
+
+#define AppendListItem(item,list)	do { \
+						CHECK_LIST_ENTRY(list) \
+						append_ListItem((ListStruct *)item, (ListStruct **)&list); \
+					} while(0)
+
+#define DelListItem(item,list)		do { \
+						CHECK_LIST_ENTRY(list) \
+						del_ListItem((ListStruct *)item, (ListStruct **)&list); \
+					} while(0)
+
+#ifndef _WIN32
+ #define CHECK_PRIO_LIST_ENTRY(list)	if (offsetof(typeof(*list),prev) != offsetof(ListStructPrio,prev)) \
+					{ \
+						ircd_log(LOG_ERROR, "[BUG] %s:%d: List operation on struct with incorrect order (->prev must be 1st struct member)", __FILE__, __LINE__); \
+						abort(); \
+					} \
+					if (offsetof(typeof(*list),next) != offsetof(ListStructPrio,next)) \
+					{ \
+						ircd_log(LOG_ERROR, "[BUG] %s:%d: List operation on struct with incorrect order (->next must be 2nd struct member))", __FILE__, __LINE__); \
+						abort(); \
+					} \
+					if (offsetof(typeof(*list),priority) != offsetof(ListStructPrio,priority)) \
+					{ \
+						ircd_log(LOG_ERROR, "[BUG] %s:%d: List operation on struct with incorrect order (->priority must be 3rd struct member))", __FILE__, __LINE__); \
+						abort(); \
+					}
+#else
+ #define CHECK_PRIO_LIST_ENTRY(list)	/* not available on Windows, typeof() not reliable */
+#endif
+
+#define AddListItemPrio(item,list,prio)	do { \
+						CHECK_PRIO_LIST_ENTRY(list); \
+						add_ListItemPrio((ListStructPrio *)item, (ListStructPrio **)&list, prio); \
+					} while(0)
+
+#define DelListItemPrio(item,list,prio)	do { \
+						CHECK_PRIO_LIST_ENTRY(list); \
+						del_ListItem((ListStruct *)item, (ListStruct **)&list); \
+					} while(0)
 
 struct liststruct {
 	ListStruct *prev, *next;
@@ -1710,7 +1770,8 @@ extern MODVAR char *gnulicense[];
 struct Command {
 	aCommand		*prev, *next;
 	char 			*cmd;
-	int			(*func) ();
+	CmdFunc			func;
+	AliasCmdFunc		aliasfunc;
 	int			flags;
 	unsigned int    	count;
 	unsigned		parameters : 5;
@@ -1730,7 +1791,7 @@ struct _cmdoverride {
 	int			priority;
 	Module			*owner;
 	aCommand		*command;
-	int			(*func)();
+	OverrideCmdFunc		func;
 };
 
 struct ThrottlingBucket
@@ -1798,7 +1859,9 @@ struct _maxtargets {
 #define BANCHK_MSG		1	/* checking if a ban forbids the person from sending messages */
 #define BANCHK_NICK		2	/* checking if a ban forbids the person from changing his/her nick */
 
-#define TKLISTLEN 26
+#define TKLISTLEN		26
+#define TKLIPHASHLEN1		4
+#define TKLIPHASHLEN2		1021
 
 #define MATCH_CHECK_IP              0x0001
 #define MATCH_CHECK_REAL_HOST       0x0002
@@ -1821,6 +1884,36 @@ typedef enum {
 
 #define NO_EXIT_CLIENT	99
 
+/*-- badwords --*/
+
+#define MAX_MATCH       1
+#define MAX_WORDLEN	64
+
+#define PATTERN		"\\w*%s\\w*"
+#define REPLACEWORD	"<censored>"
+
+#define BADW_TYPE_INVALID 0x0
+#define BADW_TYPE_FAST    0x1
+#define BADW_TYPE_FAST_L  0x2
+#define BADW_TYPE_FAST_R  0x4
+#define BADW_TYPE_REGEX   0x8
+
+#define BADWORD_REPLACE 1
+#define BADWORD_BLOCK 2
+
+typedef struct _configitem_badword ConfigItem_badword;
+
+struct _configitem_badword {
+	ConfigItem_badword      *prev, *next;
+	ConfigFlag	flag;
+	char		*word, *replace;
+	unsigned short	type;
+	char		action;
+	pcre2_code	*pcre2_expr;
+};
+
+/*-- end of badwords --*/
+
 #endif /* __struct_include__ */
 
 #include "dynconf.h"
