@@ -363,11 +363,13 @@ void remove_client_from_list(aClient *cptr)
 	{
 		if (cptr->serv->user)
 			free_user(cptr->serv->user, cptr);
+		safefree(cptr->serv->features.usermodes);
 		safefree(cptr->serv->features.chanmodes[0]);
 		safefree(cptr->serv->features.chanmodes[1]);
 		safefree(cptr->serv->features.chanmodes[2]);
 		safefree(cptr->serv->features.chanmodes[3]);
 		safefree(cptr->serv->features.software);
+		safefree(cptr->serv->features.nickchars);
 		MyFree(cptr->serv);
 #ifdef	DEBUGMODE
 		servs.inuse--;
@@ -379,9 +381,12 @@ void remove_client_from_list(aClient *cptr)
 	else
 		crem.inuse--;
 #endif
-	assert(list_empty(&cptr->client_node));
-	assert(list_empty(&cptr->client_hash));
-	assert(list_empty(&cptr->id_hash));
+	if (!list_empty(&cptr->client_node))
+		abort();
+	if (!list_empty(&cptr->client_hash))
+		abort();
+	if (!list_empty(&cptr->id_hash))
+		abort();
 	(void)free_client(cptr);
 	checklist();
 	numclients--;
