@@ -60,8 +60,8 @@ struct {
 
 static void free_config(void);
 static void init_config(void);
-DLLFUNC int antimixedutf8_config_test(ConfigFile *, ConfigEntry *, int, int *);
-DLLFUNC int antimixedutf8_config_run(ConfigFile *, ConfigEntry *, int);
+int antimixedutf8_config_test(ConfigFile *, ConfigEntry *, int, int *);
+int antimixedutf8_config_run(ConfigFile *, ConfigEntry *, int);
 
 #define SCRIPT_UNDEFINED	0
 #define SCRIPT_LATIN		1
@@ -116,8 +116,6 @@ static int utf8_charlen(const char *str)
 	{
 		if ((*str & t[k].mask) == t[k].val)
 		{
-			if (4 < k + 1)
-				return -1;
 			for (j = 0; j < k; j++)
 			{
 				if ((*(++str) & 0xC0) != 0x80)
@@ -172,7 +170,7 @@ int lookalikespam_score(const char *text)
 	return points;
 }
 
-static int override_msg(Cmdoverride *ovr, aClient *cptr, aClient *sptr, int parc, char *parv[])
+CMD_OVERRIDE_FUNC(override_msg)
 {
 	int score, ret;
 	
@@ -260,7 +258,7 @@ static void free_config(void)
 	memset(&cfg, 0, sizeof(cfg)); /* needed! */
 }
 
-DLLFUNC int antimixedutf8_config_test(ConfigFile *cf, ConfigEntry *ce, int type, int *errs)
+int antimixedutf8_config_test(ConfigFile *cf, ConfigEntry *ce, int type, int *errs)
 {
 	int errors = 0;
 	ConfigEntry *cep;
@@ -274,12 +272,6 @@ DLLFUNC int antimixedutf8_config_test(ConfigFile *cf, ConfigEntry *ce, int type,
 	
 	for (cep = ce->ce_entries; cep; cep = cep->ce_next)
 	{
-		if (!cep->ce_varname)
-		{
-			config_error("%s:%i: blank set::antimixedutf8 item",
-				cep->ce_fileptr->cf_filename, cep->ce_varlinenum);
-			errors++;
-		} else
 		if (!cep->ce_vardata)
 		{
 			config_error("%s:%i: set::antimixedutf8::%s with no value",
@@ -321,7 +313,7 @@ DLLFUNC int antimixedutf8_config_test(ConfigFile *cf, ConfigEntry *ce, int type,
 	return errors ? -1 : 1;
 }
 
-DLLFUNC int antimixedutf8_config_run(ConfigFile *cf, ConfigEntry *ce, int type)
+int antimixedutf8_config_run(ConfigFile *cf, ConfigEntry *ce, int type)
 {
 	ConfigEntry *cep;
 
