@@ -1,6 +1,7 @@
 /*
  * Channel Mode +f
- * (C) Copyright 2005-2014 Bram Matthys and The UnrealIRCd team.
+ * (C) Copyright 2005-2019 Bram Matthys and The UnrealIRCd team.
+ * License: GPLv2
  */
 
 #include "unrealircd.h"
@@ -25,6 +26,17 @@ ModuleHeader MOD_HEADER(floodprot)
 
 #define NUMFLD	6 /* 6 flood types */
 
+/** Configuration settings */
+struct {
+	unsigned char modef_default_unsettime;
+	unsigned char modef_max_unsettime;
+	long modef_boot_delay;
+} cfg;
+
+#define MODEF_DEFAULT_UNSETTIME		cfg.modef_default_unsettime
+#define MODEF_MAX_UNSETTIME		cfg.modef_max_unsettime
+#define MODEF_BOOT_DELAY		cfg.modef_boot_delay
+
 typedef struct SChanFloodProt ChanFloodProt;
 typedef struct SRemoveFld RemoveFld;
 
@@ -66,7 +78,10 @@ static int timedban_available = 0; /**< Set to 1 if extbans/timedban module is l
 #define IsFloodLimit(x)	((x)->mode.extmode & EXTMODE_FLOODLIMIT)
 
 /* Forward declarations */
+static void init_config(void);
 int floodprot_rehash_complete(void);
+int floodprot_config_test(ConfigFile *, ConfigEntry *, int, int *);
+int floodprot_config_run(ConfigFile *, ConfigEntry *, int);
 void floodprottimer_del(aChannel *chptr, char mflag);
 void floodprottimer_stopchantimers(aChannel *chptr);
 static inline char *chmodefstrhelper(char *buf, char t, char tdef, unsigned short l, unsigned char a, unsigned char r);
@@ -92,6 +107,13 @@ int floodprot_local_nickchange(aClient *sptr, char *oldnick);
 int floodprot_remote_nickchange(aClient *cptr, aClient *sptr, char *oldnick);
 int floodprot_chanmode_del(aChannel *chptr, int m);
 void userfld_free(ModData *md);
+int floodprot_stats(aClient *sptr, char *flag);
+
+MOD_TEST(floodprot)
+{
+	HookAdd(modinfo->handle, HOOKTYPE_CONFIGTEST, 0, floodprot_config_test);
+	return MOD_SUCCESS;
+}
 
 MOD_INIT(floodprot)
 {
@@ -115,6 +137,8 @@ MOD_INIT(floodprot)
 	creq.sjoin_check = cmodef_sjoin_check;
 	CmodeAdd(modinfo->handle, creq, &EXTMODE_FLOODLIMIT);
 
+	init_config();
+
 	memset(&mreq, 0, sizeof(mreq));
 	mreq.name = "floodprot";
 	mreq.type = MODDATATYPE_MEMBERSHIP;
@@ -122,7 +146,8 @@ MOD_INIT(floodprot)
 	mdflood = ModDataAdd(modinfo->handle, mreq);
 	if (!mdflood)
 	        abort();
-	
+
+	HookAdd(modinfo->handle, HOOKTYPE_CONFIGRUN, 0, floodprot_config_run);
 	HookAddPChar(modinfo->handle, HOOKTYPE_PRE_CHANMSG, 0, floodprot_pre_chanmsg);
 	HookAdd(modinfo->handle, HOOKTYPE_CHANMSG, 0, floodprot_post_chanmsg);
 	HookAdd(modinfo->handle, HOOKTYPE_KNOCK, 0, floodprot_knock);
@@ -133,6 +158,7 @@ MOD_INIT(floodprot)
 	HookAdd(modinfo->handle, HOOKTYPE_REMOTE_JOIN, 0, floodprot_join);
 	HookAdd(modinfo->handle, HOOKTYPE_CHANNEL_DESTROY, 0, cmodef_channel_destroy);
 	HookAdd(modinfo->handle, HOOKTYPE_REHASH_COMPLETE, 0, floodprot_rehash_complete);
+	HookAdd(modinfo->handle, HOOKTYPE_STATS, 0, floodprot_stats);
 	return MOD_SUCCESS;
 }
 
@@ -154,6 +180,99 @@ int floodprot_rehash_complete(void)
 	return 0;
 }
 
+static void init_config(void)
+{
+	/* This sets some default values */
+	memset(&cfg, 0, sizeof(cfg));
+	cfg.modef_default_unsettime = 0;
+	cfg.modef_max_unsettime = 60; /* 1 hour seems enough :p */
+	cfg.modef_boot_delay = 75;
+}
+
+int floodprot_config_test(ConfigFile *cf, ConfigEntry *ce, int type, int *errs)
+{
+	int errors = 0;
+
+	if (type != CONFIG_SET)
+		return 0;
+
+	if (!strcmp(ce->ce_varname, "modef-default-unsettime"))
+	{
+		if (!ce->ce_vardata)
+		{
+			config_error_empty(ce->ce_fileptr->cf_filename, ce->ce_varlinenum,
+				"set", ce->ce_varname);
+			errors++;
+		} else {
+			int v = atoi(ce->ce_vardata);
+			if ((v <= 0) || (v > 255))
+			{
+				config_error("%s:%i: set::modef-default-unsettime: value '%d' out of range (should be 1-255)",
+					ce->ce_fileptr->cf_filename, ce->ce_varlinenum, v);
+				errors++;
+			}
+		}
+	} else
+	if (!strcmp(ce->ce_varname, "modef-max-unsettime"))
+	{
+		if (!ce->ce_vardata)
+		{
+			config_error_empty(ce->ce_fileptr->cf_filename, ce->ce_varlinenum,
+				"set", ce->ce_varname);
+			errors++;
+		} else {
+			int v = atoi(ce->ce_vardata);
+			if ((v <= 0) || (v > 255))
+			{
+				config_error("%s:%i: set::modef-max-unsettime: value '%d' out of range (should be 1-255)",
+					ce->ce_fileptr->cf_filename, ce->ce_varlinenum, v);
+				errors++;
+			}
+		}
+	} else
+	if (!strcmp(ce->ce_varname, "modef-boot-delay"))
+	{
+		if (!ce->ce_vardata)
+		{
+			config_error_empty(ce->ce_fileptr->cf_filename, ce->ce_varlinenum,
+				"set", ce->ce_varname);
+			errors++;
+		} else {
+			long v = config_checkval(ce->ce_vardata, CFG_TIME);
+			if ((v < 0) || (v > 600))
+			{
+				config_error("%s:%i: set::modef-boot-delay: value '%ld' out of range (should be 0-600)",
+					ce->ce_fileptr->cf_filename, ce->ce_varlinenum, v);
+				errors++;
+			}
+		}
+	} else
+	{
+		/* Not handled by us */
+		return 0;
+	}
+
+	*errs = errors;
+	return errors ? -1 : 1;
+}
+
+int floodprot_config_run(ConfigFile *cf, ConfigEntry *ce, int type)
+{
+	if (type != CONFIG_SET)
+		return 0;
+
+	if (!strcmp(ce->ce_varname, "modef-default-unsettime"))
+		cfg.modef_default_unsettime = (unsigned char)atoi(ce->ce_vardata);
+	else if (!strcmp(ce->ce_varname, "modef-max-unsettime"))
+		cfg.modef_max_unsettime = (unsigned char)atoi(ce->ce_vardata);
+	else if (!strcmp(ce->ce_varname, "modef-boot-delay"))
+		cfg.modef_boot_delay = config_checkval(ce->ce_vardata, CFG_TIME);
+	else
+		return 0; /* not handled by us */
+
+	return 1;
+}
+
 int cmodef_is_ok(aClient *sptr, aChannel *chptr, char mode, char *param, int type, int what)
 {
 	if ((type == EXCHK_ACCESS) || (type == EXCHK_ACCESS_ERR))
@@ -383,7 +502,7 @@ invalidsyntax:
 		return EX_DENY;
 	}
 
-	/* falltrough -- should not be used */
+	/* fallthrough -- should not be used */
 	return EX_DENY;
 }
 
@@ -820,13 +939,19 @@ int floodprot_join(aClient *cptr, aClient *sptr, aChannel *chptr, char *parv[])
 	/* I'll explain this only once:
 	 * 1. if channel is +f
 	 * 2. local client OR synced server
-	 * 3. then, increase floodcounter
-	 * 4. if we reached the limit AND only if source was a local client.. do the action (+i).
-	 * Nr 4 is done because otherwise you would have a noticeflood with 'joinflood detected'
+	 * 3. server uptime more than XX seconds (if this information is available)
+	 * 4. is not a uline
+	 * 5. then, increase floodcounter
+	 * 6. if we reached the limit AND only if source was a local client.. do the action (+i).
+	 * Nr 6 is done because otherwise you would have a noticeflood with 'joinflood detected'
 	 * from all servers.
 	 */
-	if (IsFloodLimit(chptr) && (MyClient(sptr) || sptr->srvptr->serv->flags.synced) && 
-	    !IsULine(sptr) && do_floodprot(chptr, FLD_JOIN) && MyClient(sptr))
+	if (IsFloodLimit(chptr) &&
+	    (MyClient(sptr) || sptr->srvptr->serv->flags.synced) &&
+	    (sptr->srvptr->serv->boottime && (TStime() - sptr->srvptr->serv->boottime >= MODEF_BOOT_DELAY)) &&
+	    !IsULine(sptr) &&
+	    do_floodprot(chptr, FLD_JOIN) &&
+	    MyClient(sptr))
 	{
 		do_floodprot_action(chptr, FLD_JOIN, "join");
 	}
@@ -924,15 +1049,6 @@ int floodprot_post_chanmsg(aClient *sptr, aChannel *chptr, char *text, int notic
 	return 0;
 }
 
-#if 0
-int floodprot_remotejoin(aClient *cptr, aClient *acptr, aChannel *chptr, char *parv[])
-{
-	if (IsFloodLimit(chptr) && acptr->serv->flags.synced && !IsULine(acptr)) /* hope that's correctly copied? acptr/cptr fun */
-		do_floodprot(chptr, FLD_JOIN);
-	return 0;
-}
-#endif
-
 int floodprot_knock(aClient *sptr, aChannel *chptr)
 {
 	if (IsFloodLimit(chptr) && !IsULine(sptr) && do_floodprot(chptr, FLD_KNOCK) && MyClient(sptr))
@@ -1369,3 +1485,12 @@ void userfld_free(ModData *md)
 {
 	MyFree(md->ptr);
 }
+
+int floodprot_stats(aClient *sptr, char *flag)
+{
+	sendto_one(sptr, ":%s %i %s :modef-default-unsettime: %hd", me.name, RPL_TEXT,
+			sptr->name, (unsigned short)MODEF_DEFAULT_UNSETTIME);
+	sendto_one(sptr, ":%s %i %s :modef-max-unsettime: %hd", me.name, RPL_TEXT,
+			sptr->name, (unsigned short)MODEF_MAX_UNSETTIME);
+	return 0;
+}
