@@ -25,8 +25,8 @@
 /* Forward declarations */
 CMD_FUNC(m_mode);
 CMD_FUNC(m_mlock);
-DLLFUNC void _do_mode(aChannel *chptr, aClient *cptr, aClient *sptr, int parc, char *parv[], time_t sendts, int samode);
-DLLFUNC void _set_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[], u_int *pcount,
+void _do_mode(aChannel *chptr, aClient *cptr, aClient *sptr, int parc, char *parv[], time_t sendts, int samode);
+void _set_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[], u_int *pcount,
                        char pvar[MAXMODEPARAMS][MODEBUFLEN + 3], int bounce);
 CMD_FUNC(_m_umode);
 
@@ -406,7 +406,7 @@ static void bounce_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[])
  *	User or server is authorized to do the mode.  This takes care of
  * setting the mode and relaying it to other users and servers.
  */
-DLLFUNC void _do_mode(aChannel *chptr, aClient *cptr, aClient *sptr, int parc, char *parv[], time_t sendts, int samode)
+void _do_mode(aChannel *chptr, aClient *cptr, aClient *sptr, int parc, char *parv[], time_t sendts, int samode)
 {
 	char pvar[MAXMODEPARAMS][MODEBUFLEN + 3];
 	int  pcount;
@@ -480,6 +480,7 @@ DLLFUNC void _do_mode(aChannel *chptr, aClient *cptr, aClient *sptr, int parc, c
 	if (opermode == 1)
 	{
 		if (modebuf[1])
+		{
 			sendto_snomask(SNO_EYES,
 			    "*** OperOverride -- %s (%s@%s) MODE %s %s %s",
 			    sptr->name, sptr->user->username, sptr->user->realhost,
@@ -489,6 +490,7 @@ DLLFUNC void _do_mode(aChannel *chptr, aClient *cptr, aClient *sptr, int parc, c
 			ircd_log(LOG_OVERRIDE,"OVERRIDE: %s (%s@%s) MODE %s %s %s",
 				sptr->name, sptr->user->username, sptr->user->realhost,
 				chptr->chname, modebuf, parabuf);
+		}
 
 		sendts = 0;
 	}
@@ -819,6 +821,7 @@ int  do_mode_char(aChannel *chptr, long modetype, char modechar, char *param,
 					if (!is_halfop(cptr, chptr)) /* htrig will take care of halfop override notices */
 						opermode = 1;
 			}
+			goto process_listmode;
 		case MODE_CHANPROT:
 			REQUIRE_PARAMETER()
 			/* not uline, not server, not chanowner, not an samode, not -a'ing yourself... */
@@ -833,12 +836,13 @@ int  do_mode_char(aChannel *chptr, long modetype, char modechar, char *param,
 					if (!is_halfop(cptr, chptr)) /* htrig will take care of halfop override notices */
 						opermode = 1;
 			}
-
+			goto process_listmode;
 
 		case MODE_HALFOP:
 		case MODE_CHANOP:
 		case MODE_VOICE:
 			REQUIRE_PARAMETER()
+process_listmode:
 			if (!(who = find_chasing(cptr, param, &chasing)))
 				break;
 			if (!who->user)
@@ -1362,10 +1366,37 @@ int paracount_for_chanmode_from_server(aClient *acptr, u_int what, char mode)
 	return 0;
 }
 
+/** Quick way to find out parameter count for a channel mode.
+ * Only for LOCAL mode requests. For remote modes use
+ * paracount_for_chanmode_from_server() instead.
+ */
+int paracount_for_chanmode(u_int what, char mode)
+{
+	if (me.serv->features.chanmodes[0] && strchr(me.serv->features.chanmodes[0], mode))
+		return 1; /* 1 parameter for set, 1 parameter for unset */
+
+	if (me.serv->features.chanmodes[1] && strchr(me.serv->features.chanmodes[1], mode))
+		return 1; /* 1 parameter for set, 1 parameter for unset */
+
+	if (me.serv->features.chanmodes[2] && strchr(me.serv->features.chanmodes[2], mode))
+		return (what == MODE_ADD) ? 1 : 0; /* 1 parameter for set, no parameter for unset */
+
+	if (me.serv->features.chanmodes[3] && strchr(me.serv->features.chanmodes[3], mode))
+		return 0; /* no parameter for set, no parameter for unset */
+
+	/* Not found: */
+
+	/* Some additional backward compatability for +j for really old servers.. Hmm.. too nice */
+	if ((what == MODE_ADD) && (mode == 'j'))
+		return 1;
+
+	return 0;
+}
+
 /* set_mode
  *	written by binary
  */
-DLLFUNC void _set_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[], u_int *pcount,
+void _set_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[], u_int *pcount,
 	char pvar[MAXMODEPARAMS][MODEBUFLEN + 3], int bounce)
 {
 	char *curchr;
@@ -1446,10 +1477,9 @@ DLLFUNC void _set_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[], u
 				if (found == 0) /* Mode char unknown */
 				{
 					if (!MyClient(cptr))
-					    paracount += paracount_for_chanmode_from_server(cptr, what, *curchr);
+						paracount += paracount_for_chanmode_from_server(cptr, what, *curchr);
 					else
-						sendto_one(cptr, err_str(ERR_UNKNOWNMODE),
-						   me.name, cptr->name, *curchr);
+						sendto_one(cptr, err_str(ERR_UNKNOWNMODE), me.name, cptr->name, *curchr);
 					break;
 				}
 
@@ -1457,59 +1487,59 @@ DLLFUNC void _set_mode(aChannel *chptr, aClient *cptr, int parc, char *parv[], u
 				{
 					if (warnrestr)
 					{
-					sendnotice(cptr, "Setting/removing of channelmode(s) '%s' has been disabled.",
-						RESTRICT_CHANNELMODES);
-					warnrestr = 0;
+						sendnotice(cptr, "Setting/removing of channelmode(s) '%s' has been disabled.",
+							RESTRICT_CHANNELMODES);
+						warnrestr = 0;
 					}
-					paracount += foundat.parameters;
+					paracount += paracount_for_chanmode(what, *curchr);
 					break;
 				}
 
-			if (paracount < parc)
-				argument = parv[paracount]; /* can still be NULL */
-			else
-				argument = NULL;
+				if (paracount < parc)
+					argument = parv[paracount]; /* can still be NULL */
+				else
+					argument = NULL;
 
 #ifndef NO_OPEROVERRIDE
-			if (found == 1)
-			{
-				if ((Halfop_mode(modetype) == FALSE) && opermode == 2 && htrig != 1)
+				if (found == 1)
 				{
-					/* YUCK! */
-					if ((foundat.flag == 'h') && argument && (find_person(argument, NULL) == cptr))
+					if ((Halfop_mode(modetype) == FALSE) && opermode == 2 && htrig != 1)
 					{
-						/* ircop with halfop doing a -h on himself. no warning. */
-					} else {
-						opermode = 0;
-						htrig = 1;
+						/* YUCK! */
+						if ((foundat.flag == 'h') && argument && (find_person(argument, NULL) == cptr))
+						{
+							/* ircop with halfop doing a -h on himself. no warning. */
+						} else {
+							opermode = 0;
+							htrig = 1;
+						}
 					}
 				}
-			}
-			else if (found == 2) {
-				/* Extended mode: all override stuff is in do_extmode_char which will set
-				 * opermode if appropriate. -- Syzop
-				 */
-			}
+				else if (found == 2) {
+					/* Extended mode: all override stuff is in do_extmode_char which will set
+					 * opermode if appropriate. -- Syzop
+					 */
+				}
 #endif /* !NO_OPEROVERRIDE */
 
-			/* Not sure how useful this is, but I'll let it stay... */
-			if (argument && strlen(argument) >= MODEBUFLEN)
-				argument[MODEBUFLEN-1] = '\0';
+				/* Not sure how useful this is, but I'll let it stay... */
+				if (argument && strlen(argument) >= MODEBUFLEN)
+					argument[MODEBUFLEN-1] = '\0';
 
-			if (found == 1)
-			{
-				paracount += do_mode_char(chptr, modetype, *curchr,
-				                          argument, what, cptr, pcount,
-				                          pvar, bounce, my_access);
-			}
-			else if (found == 2)
-			{
-				paracount += do_extmode_char(chptr, &Channelmode_Table[extm], argument,
-				                             what, cptr, pcount, pvar, bounce);
-			}
-			break;
-		}
-	}
+				if (found == 1)
+				{
+					paracount += do_mode_char(chptr, modetype, *curchr,
+								  argument, what, cptr, pcount,
+								  pvar, bounce, my_access);
+				}
+				else if (found == 2)
+				{
+					paracount += do_extmode_char(chptr, &Channelmode_Table[extm], argument,
+								     what, cptr, pcount, pvar, bounce);
+				}
+				break;
+		} /* switch(*curchr) */
+	} /* for loop through mode letters */
 
 	make_mode_str(chptr, oldm, oldem, oldl, *pcount, pvar, modebuf, parabuf, sizeof(modebuf), sizeof(parabuf), bounce);
 
@@ -1654,6 +1684,7 @@ CMD_FUNC(_m_umode)
 						set_snomask(sptr, parv[3]);
 					goto def;
 				}
+				break;
 			case 'o':
 			case 'O':
 				if(sptr->from->flags & FLAGS_QUARANTINE)
