@@ -114,7 +114,7 @@ SpamfilterTargetTable spamfiltertargettable[] = {
 	{ SPAMF_USER,		'u',	"user",				"NICK" },
 	{ SPAMF_AWAY,		'a',	"away",				"AWAY" },
 	{ SPAMF_TOPIC,		't',	"topic",			"TOPIC" },
-	{ 0, 0, 0 }
+	{ 0, 0, 0, 0 }
 };
 
 
@@ -811,56 +811,6 @@ int valid_host(char *host)
 	return 1;
 }
 
-/** Checks if the specified regex (or fast badwords) is valid.
- * returns NULL in case of success [!],
- * pointer to buffer with error message otherwise
- * if check_broadness is 1, the function will attempt to determine
- * if the given regex string is too broad (i.e. matches everything)
- */
-char *unreal_checkregex(char *s, int fastsupport, int check_broadness)
-{
-int errorcode, errorbufsize, regex=0;
-char *errtmp, *tmp;
-static char errorbuf[512];
-regex_t expr;
-
-	if (fastsupport)
-	{
-		for (tmp = s; *tmp; tmp++) {
-			if (!isalnum(*tmp) && !(*tmp >= 128)) {
-				if ((s == tmp) && (*tmp == '*'))
-					continue;
-				if ((*(tmp + 1) == '\0') && (*tmp == '*'))
-					continue;
-				regex = 1;
-				break;
-			}
-		}
-	}
-	if (!fastsupport || regex)
-	{
-		errorcode = regcomp(&expr, s, REG_ICASE|REG_EXTENDED);
-		if (errorcode > 0)
-		{
-			errorbufsize = regerror(errorcode, &expr, NULL, 0)+1;
-			errtmp = MyMallocEx(errorbufsize);
-			regerror(errorcode, &expr, errtmp, errorbufsize);
-			strlcpy(errorbuf, errtmp, sizeof(errorbuf));
-			free(errtmp);
-			regfree(&expr);
-			return errorbuf;
-		}
-		if (check_broadness && !regexec(&expr, "", 0, NULL, 0))
-		{
-			strlcpy(errorbuf, "Regular expression is too broad", sizeof(errorbuf));
-			regfree(&expr);
-			return errorbuf;
-		}
-		regfree(&expr);
-	}
-	return NULL;
-}
-
 /*|| BAN ACTION ROUTINES FOLLOW ||*/
 
 /** Converts a banaction string (eg: "kill") to an integer value (eg: BAN_ACT_KILL) */
@@ -1323,3 +1273,59 @@ size_t add_sjsby(char *buf, char *setby, TS seton)
 
 	return p - buf;
 }
+
+/** Concatenate the entire parameter string.
+ * The function will take care of spaces in the final parameter (if any).
+ * @param buf   The buffer to output in.
+ * @param len   Length of the buffer.
+ * @param parc  Parameter count, ircd style.
+ * @param parv  Parameters, ircd style, so we will start at parv[1].
+ * @example
+ * char buf[512];
+ * concat_params(buf, sizeof(buf), parc, parv);
+ * sendto_server(cptr, 0, 0, ":%s SOMECOMMAND %s", sptr->name, buf);
+ */
+void concat_params(char *buf, int len, int parc, char *parv[])
+{
+	int i;
+
+	*buf = '\0';
+	for (i = 1; i < parc; i++)
+	{
+		char *param = parv[i];
+
+		if (!param)
+			break;
+
+		if (!*buf)
+			strlcat(buf, " ", len);
+
+		if (strchr(param, ' '))
+		{
+			/* Last parameter, with : */
+			strlcat(buf, ":", len);
+			strlcat(buf, parv[i], len);
+			break;
+		}
+		strlcat(buf, parv[i], len);
+	}
+}
+
+char *pretty_date(TS t)
+{
+	static char buf[128];
+	struct tm *tm;
+
+	if (!t)
+		time(&t);
+	tm = gmtime(&t);
+	snprintf(buf, sizeof(buf), "%04d-%02d-%02d %02d:%02d:%02d GMT",
+	         1900 + tm->tm_year,
+	         tm->tm_mon + 1,
+	         tm->tm_mday,
+	         tm->tm_hour,
+	         tm->tm_min,
+	         tm->tm_sec);
+
+	return buf;
+}
